# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEndpointCustomAttributeResult',
    'AwaitableGetEndpointCustomAttributeResult',
    'get_endpoint_custom_attribute',
    'get_endpoint_custom_attribute_output',
]

@pulumi.output_type
class GetEndpointCustomAttributeResult:
    """
    A collection of values returned by getEndpointCustomAttribute.
    """
    def __init__(__self__, attribute_name=None, attribute_type=None, id=None):
        if attribute_name and not isinstance(attribute_name, str):
            raise TypeError("Expected argument 'attribute_name' to be a str")
        pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_type and not isinstance(attribute_type, str):
            raise TypeError("Expected argument 'attribute_type' to be a str")
        pulumi.set(__self__, "attribute_type", attribute_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> _builtins.str:
        """
        The name of the attribute
        """
        return pulumi.get(self, "attribute_name")

    @_builtins.property
    @pulumi.getter(name="attributeType")
    def attribute_type(self) -> _builtins.str:
        """
        Attribute type
        """
        return pulumi.get(self, "attribute_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")


class AwaitableGetEndpointCustomAttributeResult(GetEndpointCustomAttributeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointCustomAttributeResult(
            attribute_name=self.attribute_name,
            attribute_type=self.attribute_type,
            id=self.id)


def get_endpoint_custom_attribute(id: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointCustomAttributeResult:
    """
    This data source can read the Endpoint Custom Attribute.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_custom_attribute(id="isMobile")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getEndpointCustomAttribute:getEndpointCustomAttribute', __args__, opts=opts, typ=GetEndpointCustomAttributeResult).value

    return AwaitableGetEndpointCustomAttributeResult(
        attribute_name=pulumi.get(__ret__, 'attribute_name'),
        attribute_type=pulumi.get(__ret__, 'attribute_type'),
        id=pulumi.get(__ret__, 'id'))
def get_endpoint_custom_attribute_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointCustomAttributeResult]:
    """
    This data source can read the Endpoint Custom Attribute.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_custom_attribute(id="isMobile")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getEndpointCustomAttribute:getEndpointCustomAttribute', __args__, opts=opts, typ=GetEndpointCustomAttributeResult)
    return __ret__.apply(lambda __response__: GetEndpointCustomAttributeResult(
        attribute_name=pulumi.get(__response__, 'attribute_name'),
        attribute_type=pulumi.get(__response__, 'attribute_type'),
        id=pulumi.get(__response__, 'id')))
