# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthorizationGlobalExceptionRuleUpdateRanksArgs', 'AuthorizationGlobalExceptionRuleUpdateRanks']

@pulumi.input_type
class AuthorizationGlobalExceptionRuleUpdateRanksArgs:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]] = None):
        """
        The set of arguments for constructing a AuthorizationGlobalExceptionRuleUpdateRanks resource.
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]:
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _AuthorizationGlobalExceptionRuleUpdateRanksState:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering AuthorizationGlobalExceptionRuleUpdateRanks resources.
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]:
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRanks:AuthorizationGlobalExceptionRuleUpdateRanks")
class AuthorizationGlobalExceptionRuleUpdateRanks(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        This resource is used to bulk update rank field in device admin authorization global exception rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_global_exception_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationGlobalExceptionRuleUpdateRanks("example", rules=[{
            "id": "3741aca3-db08-4899-af73-2e3f65ec31e1",
            "rank": 0,
        }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AuthorizationGlobalExceptionRuleUpdateRanksArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource is used to bulk update rank field in device admin authorization global exception rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_global_exception_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationGlobalExceptionRuleUpdateRanks("example", rules=[{
            "id": "3741aca3-db08-4899-af73-2e3f65ec31e1",
            "rank": 0,
        }])
        ```

        :param str resource_name: The name of the resource.
        :param AuthorizationGlobalExceptionRuleUpdateRanksArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthorizationGlobalExceptionRuleUpdateRanksArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthorizationGlobalExceptionRuleUpdateRanksArgs.__new__(AuthorizationGlobalExceptionRuleUpdateRanksArgs)

            __props__.__dict__["rules"] = rules
        super(AuthorizationGlobalExceptionRuleUpdateRanks, __self__).__init__(
            'ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRanks:AuthorizationGlobalExceptionRuleUpdateRanks',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None) -> 'AuthorizationGlobalExceptionRuleUpdateRanks':
        """
        Get an existing AuthorizationGlobalExceptionRuleUpdateRanks resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthorizationGlobalExceptionRuleUpdateRanksState.__new__(_AuthorizationGlobalExceptionRuleUpdateRanksState)

        __props__.__dict__["rules"] = rules
        return AuthorizationGlobalExceptionRuleUpdateRanks(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Optional[Sequence['outputs.AuthorizationGlobalExceptionRuleUpdateRanksRule']]]:
        return pulumi.get(self, "rules")

